@@ -117,7 +117,7 @@ proc portclean::clean_dist {args} {
 
     set count 0
     if {![info exists patchfiles]} {
-        set patchfiles ""
+        set patchfiles [list]
     }
     foreach file $patchfiles {
         set patchfile [getdistname $file]
@@ -144,7 +144,7 @@ proc portclean::clean_dist {args} {
     if {$dist_subdir ne $name} {
         if {!([info exists ports_force] && $ports_force eq "yes")
             && [file isdirectory $distpath]
-            && [llength [readdir $distpath]] > 0} {
+            && ![dirempty $distpath]} {
             ui_warn [format [msgcat::mc "Distfiles directory '%s' may contain distfiles needed for other ports, use the -f flag to force removal" ] $distpath]
         } else {
             lappend dirlist $dist_subdir
@@ -175,21 +175,33 @@ proc portclean::clean_dist {args} {
 }
 
 proc portclean::clean_work {args} {
-    global portbuildpath subbuildpath worksymlink
+    global portbuildpath subbuildpath worksymlink subport
 
-    if {[file isdirectory $subbuildpath]} {
-        ui_debug "Removing directory: ${subbuildpath}"
+    if {[catch {set real_subbuildpath [realpath $subbuildpath]}]} {
+        set real_subbuildpath $subbuildpath
+    }
+    if {[file isdirectory $real_subbuildpath]} {
+        ui_debug "Removing directory: ${real_subbuildpath}"
+        macports_try -pass_signal {
+            delete $real_subbuildpath
+        } on error {eMessage} {
+            ui_debug "$::errorInfo"
+            ui_error "$eMessage"
+        }
+    } else {
+        ui_debug "No work directory found to remove at ${real_subbuildpath}"
+    }
+    if {![catch {file type $subbuildpath}]} {
+        ui_debug "Removing symlink: ${subbuildpath}"
         macports_try -pass_signal {
             delete $subbuildpath
         } on error {eMessage} {
             ui_debug "$::errorInfo"
             ui_error "$eMessage"
         }
-        # silently fail if non-empty (other subports might be using portbuildpath)
-        catch {file delete $portbuildpath}
-    } else {
-        ui_debug "No work directory found to remove at ${subbuildpath}"
     }
+    # silently fail if non-empty (other subports might be using portbuildpath)
+    catch {file delete $portbuildpath}
 
     # Clean symlink, if necessary
     if {![catch {file type $worksymlink} result] && $result eq "link"} {
@@ -225,7 +237,7 @@ proc portclean::clean_archive {args} {
     if {[info exists ports_version_glob]} {
         # Match all possible archive variants that match the version
         # glob specified by the user.
-        set fileglob "$subport-[option ports_version_glob]*.*.*.*"
+        set fileglob "$subport-${ports_version_glob}*.*.*.*"
     } else {
         # Match all possible archives for this port.
         set fileglob "$subport-*_*.*.*.*"
@@ -242,17 +254,19 @@ proc portclean::clean_archive {args} {
             # thus can't be checked and aren't useful anyway.
             set archivetype [string range [file extension $path] 1 end]
             if {[file isfile $path] && ($archivetype eq "TMP"
-                || [extract_archive_metadata $path $archivetype portname] eq $subport)} {
+                || [dict get [extract_archive_metadata $path $archivetype portname] portname] eq $subport)} {
                 ui_debug "Removing archive: $path"
                 if {[catch {delete $path} result]} {
                     ui_debug "$::errorInfo"
                     ui_error "$result"
                 }
-                if {[file isfile ${path}.rmd160]} {
-                    ui_debug "Removing archive signature: ${path}.rmd160"
-                    if {[catch {delete ${path}.rmd160} result]} {
-                        ui_debug "$::errorInfo"
-                        ui_error "$result"
+                foreach sigtype {rmd160 sig} {
+                    if {[file isfile ${path}.${sigtype}]} {
+                        ui_debug "Removing archive signature: ${path}.${sigtype}"
+                        if {[catch {delete ${path}.${sigtype}} result]} {
+                            ui_debug "$::errorInfo"
+                            ui_error "$result"
+                        }
                     }
                 }
                 incr count
